summaryrefslogtreecommitdiffstats
path: root/usr.bin/fstat/fstat.c
diff options
context:
space:
mode:
Diffstat (limited to 'usr.bin/fstat/fstat.c')
-rw-r--r--usr.bin/fstat/fstat.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/usr.bin/fstat/fstat.c b/usr.bin/fstat/fstat.c
index 38736ff..eb81388 100644
--- a/usr.bin/fstat/fstat.c
+++ b/usr.bin/fstat/fstat.c
@@ -872,14 +872,14 @@ bad:
/*
* Read the specinfo structure in the kernel (as pointed to by a dev_t)
* in order to work out the associated udev_t
*/
udev_t
dev2udev(dev)
dev_t dev;
{
- struct specinfo si;
+ struct cdev si;
if (KVM_READ(dev, &si, sizeof si)) {
return si.si_udev;
OpenPOWER on IntegriCloud
@@ -872,14 +872,14 @@ bad:
/*
- * Read the specinfo structure in the kernel (as pointed to by a dev_t)
+ * Read the cdev structure in the kernel (as pointed to by a dev_t)
* in order to work out the associated udev_t
*/